#' @title Moringa Adsorption Study
#' @description Actual adosrption experiment results using Moringa oleifera seeds.
#' @format A data frame with 6 observations on the following 2 variables.
#' \describe{
#' \item{\code{Ce}}{a numeric vector}
#' \item{\code{Qe}}{a numeric vector}
#'
#' }
#'...
"moringa"

